@@ -33,8 +33,8 @@ def entry():
             f.write(ACTIVATE_PACKY_AGENT_SH.format(venv_path=os.getenv('VIRTUAL_ENV')))
         os.system(f'chmod u+x {ACTIVATE_SCRIPT_PATH}')
 
-        link = install_and_upgrade_manager.get_agent_console_url()
-        print(f'Please, activate your Packy Agent at {link} or run `sudo {ACTIVATE_SCRIPT_PATH}`')
+        url = settings.get_console_base_url()
+        print(f'Please, activate your Packy Agent at {url} or run `sudo {ACTIVATE_SCRIPT_PATH}`')
         print()
 
 
