@@ -4,6 +4,7 @@ from urllib.parse import urljoin
 import requests
 
 from packy_agent.configuration.settings import settings
+from packy_agent.utils.container import container
 
 
 logger = logging.getLogger(__name__)
@@ -24,4 +25,9 @@ class PackyAgentWorkerClient:
         return response.json()
 
 
-packy_agent_worker_client = PackyAgentWorkerClient()
+def get_packy_agent_worker_client():
+    client = getattr(container, 'packy_agent_worker_client', None)
+    if not client:
+        container.packy_agent_worker_client = client = PackyAgentWorkerClient()
+
+    return client
