@@ -5,7 +5,7 @@ from sentry_sdk.integrations.logging import LoggingIntegration
 from sentry_sdk.integrations.flask import FlaskIntegration
 
 import packy_agent
-from packy_agent.utils.platforms import is_inside_docker_container
+from packy_agent.utils.platforms import get_platform
 from packy_agent.configuration.settings import settings
 
 logger = logging.getLogger(__name__)
@@ -17,9 +17,8 @@ def init_sentry_client(flask_integration=False, packy_agent_sentry_dsn=None, **k
 
     if packy_agent_sentry_dsn:
         component = settings.get_component()
-        # TODO(dmu) MEDIUM: Improve OS/platform reporting
-        platform_name = 'Docker' if is_inside_docker_container() else 'non-Docker'
-        release = f'[{component}, {platform_name}] Packy Agent 2 v{packy_agent.__version__}'
+        platform_name = get_platform()
+        release = f'Packy Agent v{packy_agent.__version__} / {component} / {platform_name}'
 
         integrations = [LoggingIntegration(level=logging.ERROR, event_level=logging.ERROR)]
         if flask_integration:
