@@ -1,3 +1,5 @@
+from enum import Enum
+
 PING_MODULE = 'ping'
 TRACE_MODULE = 'trace'
 SPEEDTEST_MODULE = 'speedtest'
@@ -27,3 +29,8 @@ RESTART_EVENT = 'restart'
 REBOOT_EVENT = 'reboot'
 UPGRADE_EVENT = 'upgrade'
 HEARTBEAT_EVENT = 'heartbeat'
+
+
+class ErrorSide(Enum):
+    SERVER = 1
+    CLIENT = 2
