@@ -3,7 +3,7 @@ import logging
 from packy_agent.domain_logic.managers.control import control_manager
 from packy_agent.domain_logic.managers.network import network_manager
 from packy_agent.configuration.settings import settings
-from packy_agent.clients.packy_server import packy_server_client
+from packy_agent.clients.packy_server import get_packy_server_client
 
 
 logger = logging.getLogger(__name__)
@@ -15,9 +15,11 @@ class ResetManager:
         if network_manager.is_network_configuration_supported():
             network_manager.restore_configuration(
                 reboot=reboot, reboot_delay_seconds=reboot_delay_seconds)
+        else:
+            logger.debug('Network configuration is not supported')
 
     def deactivate(self, reboot=False, delay_seconds=5):
-        packy_server_client.deactivate_agent()
+        get_packy_server_client().deactivate_agent()
         settings.deactivate()
 
         if reboot:
@@ -30,4 +32,5 @@ class ResetManager:
         self.reset_network_configuration(reboot=True, reboot_delay_seconds=delay_seconds)
 
 
+# As long as manager is stateless object we do not need to care about greenlet-multitasking safety
 reset_manager = ResetManager()
