@@ -17,18 +17,27 @@ PRETTY_NAMES = {
 LINUX_MINT_18_1 = (LINUX_MINT, '18.1')
 UBUNTU_16_04 = (UBUNTU, '16.04')
 UBUNTU_18_04 = (UBUNTU, '18.04')
-RASPBIAN_9_4 = (RASPBIAN, '9.4')
-
-SUPPORTED = (LINUX_MINT_18_1, UBUNTU_16_04, UBUNTU_18_04, RASPBIAN_9_4)
+RASPBIAN_9 = (RASPBIAN, '9')
 
 
 def get_os_id_and_version():
-    return distro.id(), '.'.join(distro.version_parts(best=True)[:2])
+    distro_id = distro.id()
+    version_parts = distro.version_parts(best=True)
+    if distro_id == RASPBIAN:
+        version = version_parts[0]
+    else:
+        version = '.'.join(version_parts[:2])
 
-
-def is_operating_system_supported():
-    return get_os_id_and_version() in SUPPORTED
+    return distro_id, version
 
 
 def is_inside_docker_container():
     return os.path.isfile('/.dockerenv')
+
+
+def get_platform():
+    platform = distro.name(pretty=True) or 'unidentified'
+    if is_inside_docker_container():
+        platform = f'Docker/{platform}'
+
+    return platform
