@@ -22,11 +22,11 @@ class ProducerLoop(CallableLoop, ABC):
         self.outbound_queue = outbound_queue
 
     def call(self):
-        logger.info(f'STARTED actual work: {self.description}')
+        logger.info('STARTED actual work: %s', self.description)
         result = self.callable(*self.args, **self.kwargs)
-        logger.info(f'FINISHED actual work: {self.description}')
+        logger.info('FINISHED actual work: %s', self.description)
         if result is None:
-            logger.warning('Did not get result for %s', self.description)
+            logger.debug('Did not get result for %s', self.description)
         else:
             if self.outbound_queue:
                 self.outbound_queue.put(result)
