@@ -11,7 +11,8 @@ logger = logging.getLogger(__name__)
 def get_target(kwargs, module_name):
     target = kwargs.get('target') or kwargs.get('host')
     if not target:
-        raise ImproperlyConfiguredError(f'target (host) is not configured for {module_name}')
+        logger.debug('Target (host) is not configured for %s', module_name)
+        return
 
     return target
 
