@@ -1,7 +1,6 @@
 import logging
 
 from packy_agent.constants import HTTP_MODULE_LOOP
-from packy_agent.exceptions import ImproperlyConfiguredError
 from packy_agent.worker.loops.modules.base import ScheduledProducerTaskLoop
 from packy_agent.domain_logic.modules.http.base import get_http_measurement
 
@@ -14,7 +13,8 @@ logger = logging.getLogger(__name__)
 def http_impl(*args, **kwargs):
     url = kwargs.get('url')
     if not url:
-        raise ImproperlyConfiguredError('URLs are not configured for `http` module')
+        logger.debug('URLs are not configured for `http` module')
+        return
 
     follow_redirects = kwargs.get('follow_redirects', False)
 
@@ -22,7 +22,8 @@ def http_impl(*args, **kwargs):
     #                   workaround
     for _ in range(10):
         measurement = get_http_measurement(url, follow_redirects=follow_redirects)
-        if measurement.total_ms < 4000000 and measurement.namelookup_ms < 4000000:
+        if not measurement.is_success or (measurement.total_ms < 4000000 and
+                                          measurement.namelookup_ms < 4000000):
             break  # we got the measurement
     else:
         measurement = None
