@@ -14,10 +14,13 @@ logger = logging.getLogger(__name__)
 
 def speedtest_impl(*args, **kwargs):
     target = get_target(kwargs, SPEEDTEST_MODULE)
+    if not target:
+        return
+
     try:
         target_id = int(target)
     except (ValueError, TypeError):
-        raise ImproperlyConfiguredError('Speedtest target must be a number (not %r)', target)
+        raise ImproperlyConfiguredError(f'Speedtest target must be a number (not {target!r})')
 
     # we place it here because it also saves time momen
     measurement = SpeedtestModuleMeasurement({'target': target})
