@@ -3,8 +3,7 @@ import logging
 
 from packy_agent.worker.loops.main import MainLoop
 from packy_agent.configuration.settings import settings
-from packy_agent.clients.packy_server import packy_server_client
-from packy_agent.domain_logic.managers.install_and_upgrade import install_and_upgrade_manager
+from packy_agent.clients.packy_server import get_packy_server_client
 
 
 logger = logging.getLogger(__name__)
@@ -22,8 +21,7 @@ class Worker:
 
             activation_notify_period_seconds = settings.get_worker_activation_notify_period_seconds()
             while not settings.is_activated():
-                packy_server_client.notify_server(
-                    install_and_upgrade_manager.get_agent_console_url())
+                get_packy_server_client().notify_server(settings.get_console_base_url())
                 time.sleep(activation_notify_period_seconds)
 
         if settings.is_worker_stopped():
@@ -33,8 +31,7 @@ class Worker:
             while settings.is_worker_stopped():
                 time.sleep(started_check_period_seconds)
 
-        tasks = settings.get_tasks()
-        self.main_loop = MainLoop(tasks)
+        self.main_loop = MainLoop()
         self.main_loop.run()
 
         logger.info('STOPPED worker')
